/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 - 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.websocket.api;

/*
 * For developers who would rather implement an interface than
 * use annotations, here is an interface that can be implemented
 * to make an end point.

 * @author dannycoward
 */
public interface WSEndpoint {
    /** Called when this end point instance is first published
     * and before it accepts any connections. You can deploy instances
     * of these end points to a relative URI on the ContainerContext.
     *
     */
    public void initialize(EndpointContext epcontext);
    /** Called whenever a peer first connects to this end point.*/
    public void onOpen(Peer p);
    /** Called when a peer sends a text message to this end point.*/
    public void onMessage(Peer p, String message);
    /** Called when a peer sends a binary message to this end point.*/
    public void onMessage(Peer p, byte[] data);
    /** Called when a peer disconnects from this end point.*/
    public void onClose(Peer p, CloseEvent ce);
    /** Called when there us an error on the connection from the supplied peer
     * to this end point.
     * @param p
     * @param e
     */
    public void onError(Peer p, Exception e);
    /** Called by the container when this end point is about to be taken out of
     * service.
     */
    public void remove();

}
